@@ -1,5 +1,3 @@
-#!/usr/bin/perl -w
-
 #############################################################################
 # Math/String/Charset/Grouped.pm -- a charset of charsets for Math/String
 #
@@ -10,11 +8,11 @@ package Math::String::Charset::Grouped;
 use base Math::String::Charset;
 
 use vars qw($VERSION);
-$VERSION = 0.03;	# Current version of this package
+$VERSION = '0.05';	# Current version of this package
 require  5.005;		# requires this Perl version or later
 
 use strict;
-use Math::BigInt;
+use Math::BigInt lib => 'GMP';
 
 use vars qw/$die_on_error/;
 $die_on_error = 1;              # set to 0 to not die
